@@ -2,10 +2,11 @@
 from  sfcsim.classes import*
 import numpy as np
 from IPython.display import clear_output as clear
+import time
 class shortest_path_scheduler(dynamic_scheduler):
-    def __init__(self):
+    def __init__(self,log=True):   #log=means not to print deployment procedure information
 #         scheduler.__init__(self)
-        super(shortest_path_scheduler, self).__init__()
+        super(shortest_path_scheduler, self).__init__(log=log)
         self.__records=super(shortest_path_scheduler, self).get_records()
 
     def deploy_sfc_node_equal_nf(self,sfc,network,shortest_path,path_delay,vnf_types):   #len(shortest_path)==sfc.get_length()-2
@@ -16,15 +17,17 @@ class shortest_path_scheduler(dynamic_scheduler):
                 if self.deploy_nf_scale_out(sfc,shortest_path[i],i+1,vnf_types)!=True:
                     for j in range(i):                          #部署失败则把之前的部署都清空
                         self.remove_nf(sfc,j+1)
-                    print('error!!! can\'t deploy nf %d in %s' %(i+1,sfc.get_id()))
+                    if self.log==True:
+                        print('log:  can\'t deploy nf %d in %s on %s' %(i+1,sfc.get_id(),shortest_path[i+1].get_id()))
                     return False
             #*******************部署虚拟链路****************************************
             for i in range(nf_number+1):                          
                 if i==0:
                     if self.deploy_link(sfc,1,network,[shortest_path[0],shortest_path[0]])!=True:
-                        print('error!!! can\'t deploy link 1 in %s' %(sfc.get_id()))
                         for j in range(nf_number):                          #部署失败则把之前的部署都清空
                             self.remove_nf(sfc,j+1)
+                        if self.log==True:
+                            print('log:  can\'t deploy link 1 in %s on %s-%s' %(sfc.get_id(),shortest_path[0].get_id(),shortest_path[0].get_id()))
                         return  False
                 elif i==nf_number:
                     if self.deploy_link(sfc,i+1,network,[shortest_path[i-1],shortest_path[i-1]])!=True:
@@ -32,7 +35,8 @@ class shortest_path_scheduler(dynamic_scheduler):
                             self.remove_link(sfc,j+1,network)
                         for j in range(nf_number):                          #部署失败则把之前的部署都清空
                             self.remove_nf(sfc,j+1)
-                        print('error!!! can\'t deploy link %d in %s' %(i+1,sfc.get_id()))
+                        if self.log==True:
+                            print('log:  can\'t deploy link %d in %s %s-%s' %(i+1,sfc.get_id(),shortest_path[i-1].get_id(),shortest_path[i-1].get_id()))
                         return  False
                 else :
                     if self.deploy_link(sfc,i+1,network,[shortest_path[i-1],shortest_path[i]])!=True:
@@ -40,11 +44,13 @@ class shortest_path_scheduler(dynamic_scheduler):
                             self.remove_link(sfc,j+1,network)
                         for j in range(nf_number):                          #部署失败则把之前的部署都清空
                             self.remove_nf(sfc,j+1)
-                        print('error!!! can\'t deploy link %d in %s' %(i+1,sfc.get_id()))
+                        if self.log==True:
+                            print('log:  can\'t deploy link %d in %s on %s-%s' %(i+1,sfc.get_id(),shortest_path[i-1].get_id(),shortest_path[i].get_id()))
                         return  False
             return True
         else:
-            print('error!!! can\'t deploy sfc:%s, path delay %s > sfc delay %s' %(sfc.get_id,path_delay,sfc.get_delay()))
+            if self.log==True:
+                print('log:  can\'t deploy sfc:%s, path delay %s > sfc delay %s' %(sfc.get_id,path_delay,sfc.get_delay()))
             return False
         return True
     def deploy_sfc_node_more_than_nf(self,sfc,network,shortest_path,path_delay,vnf_types):   #len(shortest_path)>sfc.get_length()-2
@@ -59,28 +65,32 @@ class shortest_path_scheduler(dynamic_scheduler):
                     if self.deploy_nf_scale_out(sfc,shortest_path[i],i+1,vnf_types)!=True:  #index之前的nf按顺序部署
                         for j in range(i):                          #部署失败则把之前的部署都清空
                             self.remove_nf(sfc,j+1)
-                        print('error!!! can\'t deploy nf %d in %s' %(i+1,sfc.get_id()))
+                        if self.log==True:
+                            print('log:  can\'t deploy nf %d in %s on %s' %(i+1,sfc.get_id(),shortest_path[i].get_id())) 
                         return False
                 else :
                     if self.deploy_nf_scale_out(sfc,shortest_path[i+dup],i+1,vnf_types)!=True: #index之后的nf跳过dup个node顺序部署
                         for j in range(i):                          #部署失败则把之前的部署都清空
                             self.remove_nf(sfc,j+1)
-                        print('error!!! can\'t deploy nf %d in %s' %(i+1,sfc.get_id()))
+                        if self.log==True:
+                            print('log:  can\'t deploy nf %d in %s on %s' %(i+1,sfc.get_id(),shortest_path[i+dup].get_id())) 
                         return False
             #*******************部署虚拟链路****************************************
             for i in range(nf_number+1):                          
                 if i==0 :                          #虚拟链路首节点为输入节点，需要特殊部署
                     if i == index:
                         if self.deploy_link(sfc,1,network,shortest_path[0:i+dup+1])!=True:
-                            print('error!!! can\'t deploy link 1 in %s' %(sfc.get_id()))
                             for j in range(nf_number):                          #部署失败则把之前的部署都清空
                                 self.remove_nf(sfc,j+1)
+                            if self.log==True:
+                                print('log:  can\'t deploy link 1 in %s on %s-%s' %(sfc.get_id(),shortest_path[0].get_id(),shortest_path[i+dup].get_id()))
                             return  False  
                     else:
                         if self.deploy_link(sfc,1,network,[shortest_path[0],shortest_path[0]])!=True:
-                            print('error!!! can\'t deploy link 1 in %s' %(sfc.get_id()))
                             for j in range(nf_number):                          #部署失败则把之前的部署都清空
                                 self.remove_nf(sfc,j+1)
+                            if self.log==True:
+                                print('log:  can\'t deploy link 1 in %s on %s-%s' %(sfc.get_id(),shortest_path[0].get_id(),shortest_path[0].get_id()))
                             return  False       
                 elif i==nf_number:                #虚拟链路尾节点为输出节点，需要特殊部署
                     if i == index:
@@ -89,7 +99,8 @@ class shortest_path_scheduler(dynamic_scheduler):
                                 self.remove_link(sfc,j+1,network)
                             for j in range(nf_number):                          #部署失败则把之前的部署都清空
                                 self.remove_nf(sfc,j+1)
-                            print('error!!! can\'t deploy link %d in on %s%s' %(i+1,sfc.get_id(),[shortest_path[index-1].get_id(),shortest_path[node_number-1].get_id()]))
+                            if self.log==True:
+                                print('log:  can\'t deploy link %d in on %s%s' %(i+1,sfc.get_id(),[shortest_path[index-1].get_id(),shortest_path[node_number-1].get_id()]))
                             return  False
                     else:
                         if self.deploy_link(sfc,i+1,network,[shortest_path[node_number-1],shortest_path[node_number-1]])!=True:
@@ -97,23 +108,26 @@ class shortest_path_scheduler(dynamic_scheduler):
                                 self.remove_link(sfc,j+1,network)
                             for j in range(nf_number):                          #部署失败则把之前的部署都清空
                                 self.remove_nf(sfc,j+1)
-                            print('error!!! can\'t deploy link %d in %s' %(i+1,sfc.get_id()))
+                            if self.log==True:
+                                print('log:  can\'t deploy link %d in %s on %s-%s' %(i+1,sfc.get_id(),shortest_path[node_number-1].get_id(),shortest_path[node_number-1].get_id()))
                             return  False 
                 elif i<index :                     #最短代价虚拟链路之前的虚拟链路部署方案
                     if self.deploy_link(sfc,i+1,network,[shortest_path[i-1],shortest_path[i]])!=True:
                         for j in range(i):                          #部署失败则把之前的部署都清空
                             self.remove_link(sfc,j+1,network)
                         for j in range(nf_number):                          #部署失败则把之前的部署都清空
-                            self.remove_nf(sfc,j+1)    
-                        print('error!!! can\'t deploy link %d in %s' %(i+1,sfc.get_id()))
+                            self.remove_nf(sfc,j+1) 
+                        if self.log==True:
+                            print('log:  can\'t deploy link %d in %s on %s-%s' %(i+1,sfc.get_id(),shortest_path[i-1].get_id(),shortest_path[i].get_id()))  
                         return False
                 elif i==index :                    #最短代价虚拟链路部署方案
                     if self.deploy_link(sfc,i+1,network,shortest_path[i-1:i+dup+1])!=True:
                         for j in range(i):                          #部署失败则把之前的部署都清空
                             self.remove_link(sfc,j+1,network)
                         for j in range(nf_number):                          #部署失败则把之前的部署都清空
-                            self.remove_nf(sfc,j+1)    
-                        print('error!!! can\'t deploy link %d in %s' %(i+1,sfc.get_id()))
+                            self.remove_nf(sfc,j+1)  
+                        if self.log==True:
+                            print('log:  can\'t deploy link %d in %s on %s-%s' %(i+1,sfc.get_id(),shortest_path[i-1].get_id(),shortest_path[i+dup].get_id()))  
                         return False
                 else :                              #最短代价虚拟链路之后的虚拟链路部署方案
                     if self.deploy_link(sfc,i+1,network,[shortest_path[i-1+dup],shortest_path[i+dup]])!=True:
@@ -121,11 +135,13 @@ class shortest_path_scheduler(dynamic_scheduler):
                             self.remove_link(sfc,j+1,network)
                         for j in range(nf_number):                          #部署失败则把之前的部署都清空
                             self.remove_nf(sfc,j+1) 
-                        print('error!!! can\'t deploy link %d in %s' %(i+1,sfc.get_id()))
+                        if self.log==True:
+                            print('log:  can\'t deploy link %d in %s on %s-%s' %(i+1,sfc.get_id(),shortest_path[i-1+dup].get_id(),shortest_path[i+dup].get_id()))  
                         return False
             return True
         else:
-            print('error!!! can\'t deploy sfc:%s, path delay %s > sfc delay %s' %(sfc.get_id(),path_delay,sfc.get_delay()))
+            if self.log==True:
+                print('log:  can\'t deploy sfc:%s, path delay %s > sfc delay %s' %(sfc.get_id(),path_delay,sfc.get_delay()))
             return False
     def deploy_sfc_node_less_than_nf(self,sfc,network,shortest_path,path_delay,vnf_types):   #len(shortest_path)<sfc.get_length()-2
         if path_delay<=sfc.get_delay():                       #判断链路延迟是否满足需求
@@ -143,23 +159,26 @@ class shortest_path_scheduler(dynamic_scheduler):
                     if self.deploy_nf_scale_out(sfc,shortest_path[i-alerady_dup-1],i+1,vnf_types)!=True:  #表示此nf与上一个nf部署在同一个节点上
                         for j in range(i):                          #部署失败则把之前的部署都清空
                             self.remove_nf(sfc,j+1)
-                        print('error!!! can\'t deploy nf %d in %s' %(i+1,sfc.get_id()))
+                        if self.log==True:
+                            print('log:  can\'t deploy nf%d in %s on %s' %(i+1,sfc.get_id(),shortest_path[i-alerady_dup-1].get_id())) 
                         return False
                     alerady_dup+=1
                 else :
                     if self.deploy_nf_scale_out(sfc,shortest_path[i-alerady_dup],i+1,vnf_types)!=True: #
                         for j in range(i):                          #部署失败则把之前的部署都清空
                             self.remove_nf(sfc,j+1)
-                        print('error!!! can\'t deploy nf %d in %s' %(i+1,sfc.get_id()))
+                        if self.log==True:
+                            print('log:  can\'t deploy nf%d in %s on %s' %(i+1,sfc.get_id(),shortest_path[i-alerady_dup].get_id())) 
                         return False
             #*******************部署虚拟链路****************************************
             alerady_dup=0
             for i in range(nf_number+1):                          
                 if i==0:
                     if self.deploy_link(sfc,1,network,[shortest_path[0],shortest_path[0]])!=True:
-                        print('error!!! can\'t deploy link 1 in %s' %(sfc.get_id()))
                         for j in range(nf_number):                          #部署失败则把之前的部署都清空
                             self.remove_nf(sfc,j+1)
+                        if self.log==True:
+                            print('log:  can\'t deploy link %d in %s on %s-%s' %(1,sfc.get_id(),shortest_path[0].get_id(),shortest_path[0].get_id()))  
                         return False
                 elif i==nf_number:
                     if self.deploy_link(sfc,i+1,network,[shortest_path[node_number-1],shortest_path[node_number-1]])!=True:
@@ -167,7 +186,8 @@ class shortest_path_scheduler(dynamic_scheduler):
                             self.remove_link(sfc,j+1,network)
                         for j in range(nf_number):                          #部署失败则把之前的部署都清空
                             self.remove_nf(sfc,j+1)
-                        print('error!!! can\'t deploy link %d in %s:%s' %(i+1,sfc.get_id(),[shortest_path[node_number-1].get_id(),shortest_path[node_number-1].get_id()]))
+                        if self.log==True:
+                            print('log:  can\'t deploy link %d in %s on %s-%s' %(i+1,sfc.get_id(),shortest_path[node_number-1].get_id(),shortest_path[node_number-1].get_id())) 
                         return False
                 elif i in indexs :
                     if self.deploy_link(sfc,i+1,network,[shortest_path[i-1-alerady_dup],shortest_path[i-1-alerady_dup]])!=True:
@@ -175,7 +195,8 @@ class shortest_path_scheduler(dynamic_scheduler):
                             self.remove_link(sfc,j+1,network)
                         for j in range(nf_number):                          #部署失败则把之前的部署都清空
                             self.remove_nf(sfc,j+1)
-                        print('error!!! can\'t deploy link %d in %s:%s' %(i+1,sfc.get_id(),[shortest_path[i-1-alerady_dup].get_id(),shortest_path[i-1-alerady_dup].get_id()]))
+                        if self.log==True:
+                            print('log:  can\'t deploy link %d in %s on %s-%s' %(i+1,sfc.get_id(),shortest_path[i-1-alerady_dup].get_id(),shortest_path[i-1-alerady_dup].get_id())) 
                         return False
                     alerady_dup+=1
                 else:
@@ -184,11 +205,13 @@ class shortest_path_scheduler(dynamic_scheduler):
                             self.remove_link(sfc,j+1,network)
                         for j in range(nf_number):                          #部署失败则把之前的部署都清空
                             self.remove_nf(sfc,j+1)
-                        print('error!!! can\'t deploy link %d in %s' %(i+1,sfc.get_id()))
+                        if self.log==True:
+                            print('log:  can\'t deploy link %d in %s on %s-%s' %(i+1,sfc.get_id(),shortest_path[i-1-alerady_dup].get_id(),shortest_path[i-alerady_dup].get_id())) 
                         return False
             return True
         else:
-            print('error!!! can\'t deploy sfc:%s, path delay %s > sfc delay %s' %(sfc.get_id(),path_delay,sfc.get_delay()))
+            if self.log==True:
+                print('log:  can\'t deploy sfc:%s, path delay %s > sfc delay %s' %(sfc.get_id(),path_delay,sfc.get_delay()))
             return False
     def bubbleSort(self,arr): #冒泡排序，先部署流量大的vnf
         n = len(arr)
@@ -238,7 +261,7 @@ class shortest_path_scheduler(dynamic_scheduler):
 
 
 
-    def deploy_sfcs_with_draw(self,network,vnf_types,sfcs,path='',sort=True):
+    def deploy_sfcs_with_draw(self,network,vnf_types,sfcs,path='',sort=True,period=0.5):
         if(sort==True):
             self.bubbleSort(sfcs.get_sfcs())
         p=nx.shortest_path(network.G, weight='delay')          #所有节点到所有节点的最短路径集合
@@ -247,12 +270,12 @@ class shortest_path_scheduler(dynamic_scheduler):
         for sfc in sfc_list:
             if self.deploy_sfc(network,sfc,p,delay_list,vnf_types)==True:
                 self.add_sfc_record(sfc)
-                clear()
                 if(path==''):
                     network.draw_dynamic()
-                    time.sleep(0.5)
+                    plt.pause(period)
                 else:
                     network.draw_dynamic(path=(path+'/'+sfc.get_id()))
+                    plt.pause(period)
 
             else:
                 if sfc.get_id() in self.__records:
